﻿## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.

init -1 python hide:

    ## Should we enable the use of developer tools? This should be
    ## set to False before the game is released, so the user can't
    ## cheat using developer tools.

    config.developer = True

    ## These control the width and height of the screen.

    config.screen_width = 1366
    config.screen_height = 768

    ## This controls the title of the window, when Ren'Py is
    ## running in a window.

    config.window_title = u"MLD Storage"

    # These control the name and version of the game, that are reported
    # with tracebacks and other debugging logs.
    config.name = "MLD Storage"
    config.version = "0.0"

    #########################################
    # Themes

    ## We then want to call a theme function. themes.roundrect is
    ## a theme that features the use of rounded rectangles. It's
    ## the only theme we currently support.
    ##
    ## The theme function takes a number of parameters that can
    ## customize the color scheme.

    theme.bordered(

        ## The color of an idle widget face.
        widget = "#8833ce",

        ## The color of a focused widget face.
        widget_hover = "#cd249b",

        ## The color of the text in a widget.
        widget_text = "#000000",

        ## The color of the text in a selected widget. (For
        ## example, the current value of a preference.)
        widget_selected = "#b6d754",

        ## The color of a disabled widget face.
        disabled = "#57cdff",

        ## The color of disabled widget text.
        disabled_text = "#717be5",

        ## The color of informational labels.
        label = "#fff",

        ## The color of a frame containing widgets.
        frame = "#04b4ff",

        ## The background of the main menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        mm_root = "#cd249b",

        ## The background of the game menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        gm_root = "#cd249b",

        ## If this is True, the in-game window is rounded. If False,
        ## the in-game window is square.
        rounded_window = False,

        ## And we're done with the theme. The theme will customize
        ## various styles, so if we want to change them, we should
        ## do so below.
        )


    #########################################
    ## These settings let you customize the window containing the
    ## dialogue and narration, by replacing it with an image.

    ## The background of the window. In a Frame, the two numbers
    ## are the size of the left/right and top/bottom borders,
    ## respectively.

    # style.window.background = Frame("frame.png", 12, 12)

    ## Margin is space surrounding the window, where the background
    ## is not drawn.

    # style.window.left_margin = 6
    # style.window.right_margin = 6
    # style.window.top_margin = 6
    # style.window.bottom_margin = 6

    ## Padding is space inside the window, where the background is
    ## drawn.

    # style.window.left_padding = 6
    # style.window.right_padding = 6
    # style.window.top_padding = 6
    # style.window.bottom_padding = 6

    ## This is the minimum height of the window, including the margins
    ## and padding.

    # style.window.yminimum = 250
    
    style.say_who_window.background = "namebox.png"
    
    style.battle_frame_window.background = "battle_frame.png"
    #style.battle_frame_window.xanchor = 450
    #style.battle_frame_window.yanchor = 570
    
    style.battle_frame_window_text.color="#ffffff"
    style.battle_frame_window_text.xminimum = int(config.screen_width * 300)
    style.battle_frame_window_text.xmaximum = int(config.screen_width * 300)
    style.battle_frame_window_text.size = 23
    style.battle_frame_window.top_padding = 45
    style.battle_frame_window.bottom_padding = 40
    style.battle_frame_window.right_padding = -80
    style.battle_frame_window.left_padding = 160
    
    style.map_frame_text.color="#ffffff"
    style.map_frame_text.size = 20
    style.map_frame_frame.background = Frame("frame.png", 24, 24)
    style.map_frame_frame.xpadding = 30
    style.map_frame_frame.top_padding = 40
    style.map_frame_frame.bottom_padding = 15
    style.map_frame_frame.ymargin = 10
    style.map_frame_button_text.size = 17
    style.map_frame_button.xalign = .5
    style.map_frame_button.yalign = .9
    
    style.objective_frame_text.color="#ffffff"
    style.objective_frame_text.size = 19
    style.objective_frame_frame.background = Frame("frame.png", 24, 24)
    style.objective_frame_frame.left_padding = 40
    style.objective_frame_frame.right_padding = 50
    style.objective_frame_frame.top_padding = 35
    style.objective_frame_frame.bottom_padding = 20
    style.objective_frame_frame.ymargin = 10
    style.objective_frame_button_text.size = 17
    style.objective_frame_button.xalign = .5
    style.objective_frame_button.yalign = .9
    
    style.calendar_frame_text.color="#ffffff"
    style.calendar_frame_text.size = 17
    style.calendar_frame_frame.background = Frame("frame.png", 24, 24)
    style.calendar_frame_frame.xpadding = 13
    style.calendar_frame_frame.top_padding = 13
    style.calendar_frame_frame.bottom_padding = 14
    style.calendar_frame_frame.ymargin = 10
    style.calendar_frame_button_text.size = 17
    style.calendar_frame_button.xalign = .5
    style.calendar_frame_button.yalign = .9
    
    style.update_map_frame_text.color="#ffffff"
    style.update_map_frame_text.size = 19
    style.update_map_frame_text.xalign = .5
    style.update_map_frame_frame.background = Frame("frame.png", 24, 24)
    #style.update_map_frame_frame.xpadding = 30
    style.update_map_frame_frame.top_padding = 25
    style.update_map_frame_frame.bottom_padding = 20
    style.update_map_frame_frame.xmargin = 340
    style.update_map_frame_frame.ymargin = 180
    style.update_map_frame_button_text.size = 20
    style.update_map_frame_button.xalign = .5
    style.update_map_frame_button.yalign = .9
    
    style.update_text.color="#ffffff"
    style.update_text.size = 18
    #style.update_text.xalign = .9
    style.update_button_text.size = 18
    style.update_button.xalign = .5
    style.update_button.yalign = .9
    
    style.update_stat_text.color="#ffffff"
    style.update_stat_text.size = 15
    #style.update_stat_text.xalign = .5
    
    style.update_note_text.size = 17
    style.update_note_text.color="#ffffff"
    
    style.memo_text.color="#000000"
    style.memo_text.size = 18
    style.memo_text.font = "handwriting.ttf"
    style.memo_text.xalign = .5
    #style.memo_text.xpadding = 40
    style.memo_frame.xfill=False
    style.memo_frame.background = Frame("frame3.png", 24, 24)
    #style.memo_frame.xpadding = 30
    style.memo_frame.top_padding = 8
    style.memo_frame.bottom_padding = 8
    #style.memo_frame.xmargin = 250
    #style.memo_frame.ymargin = 50
    style.memo_button_text.size = 25
    style.memo_button.xalign = 1.2
    #style.memo_button.yalign = 0.00001
    style.memo_button_text.color="#000"
    style.memo_button_text.hover_color = "#A40000"
    
    style.memo2_text.color="#000000"
    style.memo2_text.size = 18
    style.memo2_text.font = "type4.ttf"
    style.memo2_text.xalign = .5
    #style.memo2_text.xpadding = 40
    style.memo2_frame.xfill=False
    style.memo2_frame.background = Frame("frame4.png", 24, 24)
    #style.memo2_frame.xpadding = 30
    style.memo2_frame.top_padding = 8
    style.memo2_frame.bottom_padding = 8
    #style.memo2_frame.xmargin = 250
    #style.memo2_frame.ymargin = 50
    style.memo2_button_text.size = 25
    style.memo2_button.xalign = 1.2
    #style.memo2_button.yalign = 0.00001
    style.memo2_button_text.color="#000"
    style.memo2_button_text.hover_color = "#A40000"
    
    style.memo_x_button_text.size = 25
    style.memo_x_button.xalign = 1.0
    style.memo_x_button.yalign = 0.1
    style.memo_x_button.right_padding = 5
    style.memo_x_button_text.color="#5A5A5A"
    style.memo_x_button_text.hover_color = "#A40000"
    
    style.begin_map_frame_text.size = 33
    style.begin_map_frame_text.xalign = .5
    style.begin_map_frame_frame.background = Frame("frame.png", 24, 24)
    style.begin_map_frame_frame.top_padding = 22
    style.begin_map_frame_frame.bottom_padding = 22
    style.begin_map_frame_button_text.size = 23
    style.begin_map_frame_button.xalign = .5
    
    style.GridStatsWindow2_text.font = "DejaVuSans.ttf"
    
    style.fight_button_text.color="#000000"
    #style.fight_button_text.hover_underline=True
    style.button_text.hover_color = "#fff"
    style.fight_button_text.hover_color = "#A40000"
    
    style.window.background = "window.png"
    style.button_text.color="#fff"
    style.button_text.hover_color = "#A40000"
    style.button.background = None
    style.button_text.selected_hover_color = "#A40000"
    style.button_text.selected_idle_color = "#5e5e5e"
    style.button_text.insensitive_color = "#4448"
    #style.button_text.hover_underline = True
    
    ## Margin is space surrounding the window, where the background
    ## is not drawn.

    #style.window.left_margin = 20
    #style.window.right_margin = 40
    #style.window.top_margin = 35
    #style.window.bottom_margin = 6

    ## Padding is space inside the window, where the background is
    ## drawn.

    style.sub_window.left_margin = 300
    style.sub_window.right_margin = 140
    #style.sub_window.background = None
    #style.sub_window.left_padding = 80
    style.sub_window.bottom_padding = 80
    
    
    style.window.left_padding = 80
    style.window.right_padding = 400
    style.window.top_padding = 60
    style.window.bottom_padding = 10
    
    style.window.xpos = 0.615

    #style.button_text.color="#000000"
    
    #style.button_frame.color="#ffffff"
    
    
    #Defines character names in the window in gridbattles
    style.battlecharacter_text.color="#fff"
    style.battlecharacter_text.xalign = 0.15
    
    #Defines voxpop discussions
    style.voxpop_frame.idle_color = "#ffffff"
    style.voxpop_frame.background = Frame("frame.png", 24, 24)
    style.voxpop_frame.xpadding = 30
    style.voxpop_frame.ypadding = 50
    style.voxpop_frame.xalign=0.5
    style.voxpop_frame.yalign=0.5
    style.voxpop_text.color="#fff"
    style.voxpop_text.size =28
    #style.voxpop_button_text.color="#fff"
    #style.voxpop_button_text.hover_color = "#fff"
    
    
    #Defines the window
    #style.say_who_window.left_padding = 300
    #style.say_who_window.right_padding = 1
    #style.say_who_window.bottom_padding = 100
    #style.say_who_window.bottom_padding = 1
    
    #style.say_who_window.left_margin = 30
    #style.say_who_window.right_margin = 1
    #style.say_who_window.top_margin = 10
    #style.say_who_window.bottom_margin = 1
    
    style.say_who_window.xanchor = -100
    style.say_who_window.yanchor = 40
    #style.say_label.xpos = 0.08
    #style.say_label.ypos = 0.
    style.say_label.xpos = -30
    style.say_label.ypos = -30
    #style.say_label.xalign = 0.08
    #style.say_label.yalign = 0.9
    #style.say_label.xoffset = 0.08
    #style.say_label.yoffset = 0.9
    
    #style.say_dialogue.ypos = 1.0
    
    ## This is the minimum height of the window, including the margins
    ## and padding.

    style.window.yminimum = 170
    #style.say_who_window.minimum = 70



    #########################################
    ## This lets you change the placement of the main menu.

    ## The way placement works is that we find an anchor point
    ## inside a displayable, and a position (pos) point on the
    ## screen. We then place the displayable so the two points are
    ## at the same place.

    ## An anchor/pos can be given as an integer or a floating point
    ## number. If an integer, the number is interpreted as a number
    ## of pixels from the upper-left corner. If a floating point,
    ## the number is interpreted as a fraction of the size of the
    ## displayable or screen.

    # style.mm_menu_frame.xpos = 0.5
    # style.mm_menu_frame.xanchor = 0.5
    # style.mm_menu_frame.ypos = 0.75
    # style.mm_menu_frame.yanchor = 0.5


    #########################################
    ## These let you customize the default font used for text in Ren'Py.

    ## The file containing the default font.

    style.default.font = "type.otf"
    # style.default.font = "DejaVuSans.ttf"

    ## The default size of text.

    # style.default.size = 22

    ## Note that these only change the size of some of the text. Other
    ## buttons have their own styles.


    #########################################
    ## These settings let you change some of the sounds that are used by
    ## Ren'Py.

    ## Set this to False if the game does not have any sound effects.

    config.has_sound = True

    ## Set this to False if the game does not have any music.

    config.has_music = True

    ## Set this to True if the game has voicing.

    config.has_voice = False

    ## Sounds that are used when button and imagemaps are clicked.

    # style.button.activate_sound = "click.wav"
    # style.imagemap.activate_sound = "click.wav"

    ## Sounds that are used when entering and exiting the game menu.

    # config.enter_sound = "click.wav"
    # config.exit_sound = "click.wav"

    ## A sample sound that can be played to check the sound volume.

    # config.sample_sound = "click.wav"

    ## Music that is played while the user is at the main menu.

    # config.main_menu_music = "main_menu_theme.ogg"


    #########################################
    ## Help.

    ## This lets you configure the help option on the Ren'Py menus.
    ## It may be:
    ## - A label in the script, in which case that label is called to
    ##   show help to the user.
    ## - A file name relative to the base directory, which is opened in a
    ##   web browser.
    ## - None, to disable help.
    config.help = "README.html"


    #########################################
    ## Transitions.

    ## Used when entering the game menu from the game.
    config.enter_transition = None

    ## Used when exiting the game menu to the game.
    config.exit_transition = None

    ## Used between screens of the game menu.
    config.intra_transition = None

    ## Used when entering the game menu from the main menu.
    config.main_game_transition = None

    ## Used when returning to the main menu from the game.
    config.game_main_transition = None

    ## Used when entering the main menu from the splashscreen.
    config.end_splash_transition = None

    ## Used when entering the main menu after the game has ended.
    config.end_game_transition = None

    ## Used when a game is loaded.
    config.after_load_transition = None

    ## Used when the window is shown.
    config.window_show_transition = None

    ## Used when the window is hidden.
    config.window_hide_transition = None

    ## Used when showing NVL-mode text directly after ADV-mode text.
    config.adv_nvl_transition = dissolve

    ## Used when showing ADV-mode text directly after NVL-mode text.
    config.nvl_adv_transition = dissolve

    ## Used when yesno is shown.
    config.enter_yesno_transition = None

    ## Used when the yesno is hidden.
    config.exit_yesno_transition = None

    ## Used when entering a replay
    config.enter_replay_transition = None

    ## Used when exiting a replay
    config.exit_replay_transition = None

    ## Used when the image is changed by a say statement with image attributes.
    config.say_attribute_transition = None

    #########################################
    ## This is the name of the directory where the game's data is
    ## stored. (It needs to be set early, before any other init code
    ## is run, so the persisten information can be found by the init code.)
python early:
    config.save_directory = "MLD Storage-1389059346"

init -1 python hide:
    #########################################
    ## Default values of Preferences.

    ## Note: These options are only evaluated the first time a
    ## game is run. To have them run a second time, delete
    ## game/saves/persistent

    ## Should we start in fullscreen mode?

    config.default_fullscreen = False

    ## The default text speed in characters per second. 0 is infinite.

    config.default_text_cps = 0

    ## The default auto-forward time setting.

    config.default_afm_time = 10

    #########################################
    ## More customizations can go here.


## This section contains information about how to build your project into
## distribution files.
init python:

    ## The name that's used for directories and archive files. For example, if
    ## this is 'mygame-1.0', the windows distribution will be in the
    ## directory 'mygame-1.0-win', in the 'mygame-1.0-win.zip' file.
    build.directory_name = "MLD-Storage-1.0"

    ## The name that's uses for executables - the program that users will run
    ## to start the game. For example, if this is 'mygame', then on Windows,
    ## users can click 'mygame.exe' to start the game.
    build.executable_name = "MLD Storage"

    ## If True, Ren'Py will include update information into packages. This
    ## allows the updater to run.
    build.include_update = False

    ## File patterns:
    ##
    ## The following functions take file patterns. File patterns are case-
    ## insensitive, and matched against the path relative to the base
    ## directory, with and without a leading /. If multiple patterns match,
    ## the first is used.
    ##
    ##
    ## In a pattern:
    ##
    ## /
    ##     Is the directory separator.
    ## *
    ##     Matches all characters, except the directory separator.
    ## **
    ##     Matches all characters, including the directory separator.
    ##
    ## For example:
    ##
    ## *.txt
    ##     Matches txt files in the base directory.
    ## game/**.ogg
    ##     Matches ogg files in the game directory or any of its subdirectories.
    ## **.psd
    ##    Matches psd files anywhere in the project.

    ## Classify files as None to exclude them from the built distributions.

    build.classify('**~', None)
    build.classify('**.bak', None)
    build.classify('**/.**', None)
    build.classify('**/#**', None)
    build.classify('**/thumbs.db', None)

    ## To archive files, classify them as 'archive'.

    # build.classify('game/**.png', 'archive')
    # build.classify('game/**.jpg', 'archive')

    ## Files matching documentation patterns are duplicated in a mac app
    ## build, so they appear in both the app and the zip file.

    build.documentation('*.html')
    build.documentation('*.txt')
    